@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -97,12 +97,25 @@ class Sensor:
     @classmethod
     def bytes_to_u16(cls, msb: int, lsb: int):
         """
-        Converts two bytes to unsigned 16bit ingeter
+        Converts two bytes to unsigned 16bit integer
         :param msb: most significant bit
         :param lsb: least significant bit
         """
         return (msb << 8) | lsb
 
+    @classmethod
+    def bytes_to_s16(cls, msb: int, lsb: int):
+        """
+        Converts two bytes to signed 16bit integer
+        :param msb: most significant bit
+        :param lsb: least significant bit
+        """
+
+        out = (msb << 8) | lsb
+        if out > 32767:
+            out -= 65536
+        return out
+
     @classmethod
     def get_float(cls, arr):
         """
@@ -348,7 +361,8 @@ class I2CSensor(Sensor):
         Read an signed 16-bit value from the specified register, in little
         endian byte order.
         """
-        out = self.bytes_to_u16(reg1, reg2)
+
+        out = self.getU16(reg1, reg2)
         if out is not None:
             if out > 32767:
                 out -= 65536
