@@ -1,43 +1,12 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
-# The MIT License (MIT)
-#
-# Copyright (c) 2016 Radomir Dopieralski (@deshipu),
-#               2017 Robert Hammelrath (@robert-hh)
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-
 """
 Sensor Class for ADS1015
 
 """
 
-__author__ = "Konstantin Niehaus"
-__copyright__ = "German Aerospace Center"
-__credits__ = ["Konstantin Niehaus", "Radomir Dopieralski", "Rober Hammelrath"]
-__license__ = ""
-__version__ = "0.1.0"
-__email__ = "konstantin.niehaus@dlr.de"
-
 from ..core.sensor import I2CSensor
 from ..core.error import Error
 
@@ -199,7 +168,7 @@ class ADS1015(I2CSensor):
             return False
 
     def raw_to_v(self, raw):
-        """ convert raw data to voltage """
+        """convert raw data to voltage"""
         res = None
         if raw is not None:
             v_p_b = _GAINS_V[self.gain] / 32767.0
