@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -8,7 +8,7 @@ based on
 https://github.com/adafruit/Adafruit_Python_BME280
 Copyright (c) 2014 Adafruit Industries
 Author: Tony DiCola
-Based on the BMp280 driver with BME280 changes provided by
+Based on the BMP280 driver with BME280 changes provided by
 David J Taylor, Edinburgh (www.satsignal.eu). Additional functions added
 by Tom Nardi (www.ifail.com)
 """
@@ -24,6 +24,10 @@ import time
 from ..core.error import Error
 from ..core.sensor import I2CSensor
 
+import logging
+
+logging.basicConfig(level=logging.DEBUG)
+
 
 class BME280(I2CSensor):
     """
@@ -40,6 +44,9 @@ class BME280(I2CSensor):
 
     # BME280 default address.
     _SENSOR_ADDRESS = 0x77
+    _MODE_SLEEP = 0x00
+    _MODE_FORCE = 0x01
+    _MODE_NORMAL = 0x03
 
     # Maximum clock frequency [Hz]
     _i2c_freq = 4e5
@@ -70,51 +77,51 @@ class BME280(I2CSensor):
     __FILTER_16 = 4
 
     # Trimming parameter registers
-    __REGISTER_T1_LSB = 0x88
-    __REGISTER_T1_MSB = 0x89
-    __REGISTER_T2_LSB = 0x8A
-    __REGISTER_T2_MSB = 0x8B
-    __REGISTER_T3_LSB = 0x8C
-    __REGISTER_T3_MSB = 0x8D
+    _REG_T1_LSB = 0x88
+    _REG_T1_MSB = 0x89
+    _REG_T2_LSB = 0x8A
+    _REG_T2_MSB = 0x8B
+    _REG_T3_LSB = 0x8C
+    _REG_T3_MSB = 0x8D
 
-    __REGISTER_P1_LSB = 0x8E
-    __REGISTER_P1_MSB = 0x8F
-    __REGISTER_P2_LSB = 0x90
-    __REGISTER_P2_MSB = 0x91
-    __REGISTER_P3_LSB = 0x92
-    __REGISTER_P3_MSB = 0x93
-    __REGISTER_P4_LSB = 0x94
-    __REGISTER_P4_MSB = 0x95
-    __REGISTER_P5_LSB = 0x96
-    __REGISTER_P5_MSB = 0x97
-    __REGISTER_P6_LSB = 0x98
-    __REGISTER_P6_MSB = 0x99
-    __REGISTER_P7_LSB = 0x9A
-    __REGISTER_P7_MSB = 0x9B
-    __REGISTER_P8_LSB = 0x9C
-    __REGISTER_P8_MSB = 0x9D
-    __REGISTER_P9_LSB = 0x9E
-    __REGISTER_P9_MSB = 0x9F
+    _REG_P1_LSB = 0x8E
+    _REG_P1_MSB = 0x8F
+    _REG_P2_LSB = 0x90
+    _REG_P2_MSB = 0x91
+    _REG_P3_LSB = 0x92
+    _REG_P3_MSB = 0x93
+    _REG_P4_LSB = 0x94
+    _REG_P4_MSB = 0x95
+    _REG_P5_LSB = 0x96
+    _REG_P5_MSB = 0x97
+    _REG_P6_LSB = 0x98
+    _REG_P6_MSB = 0x99
+    _REG_P7_LSB = 0x9A
+    _REG_P7_MSB = 0x9B
+    _REG_P8_LSB = 0x9C
+    _REG_P8_MSB = 0x9D
+    _REG_P9_LSB = 0x9E
+    _REG_P9_MSB = 0x9F
 
-    __REGISTER_H1 = 0xA1
-    __REGISTER_H2_LSB = 0xE1
-    __REGISTER_H2_MSB = 0xE2
-    __REGISTER_H3 = 0xE3
-    __REGISTER_H4_LSB = 0xE5
-    __REGISTER_H4_MSB = 0xE4
-    __REGISTER_H5_LSB = 0xE5
-    __REGISTER_H5_MSB = 0xE6
-    __REGISTER_H6 = 0xE7
+    _REG_H1 = 0xA1
+    _REG_H2_LSB = 0xE1
+    _REG_H2_MSB = 0xE2
+    _REG_H3 = 0xE3
+    _REG_H4_LSB = 0xE5
+    _REG_H4_MSB = 0xE4
+    _REG_H5_LSB = 0xE5
+    _REG_H5_MSB = 0xE6
+    _REG_H6 = 0xE7
 
-    __REGISTER_CHIPID = 0xD0
-    __REGISTER_VERSION = 0xD1
-    __REGISTER_SOFTRESET = 0xE0
+    _REG_CHIPID = 0xD0
+    _REG_VERSION = 0xD1
+    _REG_SOFTRESET = 0xE0
 
-    __REGISTER_STATUS = 0xF3
-    __REGISTER_CONTROL_HUM = 0xF2
-    __REGISTER_CONTROL = 0xF4
-    __REGISTER_CONFIG = 0xF5
-    __REGISTER_DATA = 0xF7
+    _REG_STATUS = 0xF3
+    _REG_CONTROL_HUM = 0xF2
+    _REG_CONTROL = 0xF4
+    _REG_CONFIG = 0xF5
+    _REG_DATA = 0xF7
 
     t1, t2, t3 = [None] * 3
 
@@ -127,26 +134,27 @@ class BME280(I2CSensor):
 
     t_fine = 0.0
 
-    # pylint: disable=too-many-instance-attributes
-    # Reasonable due to the number needed calib values
-
     def __init__(
         self,
         *args,
         t_mode: int = __OSAMPLE_1,
-        p_mode: int = __OSAMPLE_1,
+        p_mode: int = __OSAMPLE_16,
         h_mode: int = __OSAMPLE_1,
         standby: int = __STANDBY_250,
         _filter: int = __FILTER_off,
         **kwargs
-    ):
+    ) -> None:
         """
-        :param t_mode:
-        :param p_mode:
-        :param h_mode:
-        :param standby:
-        :param filter:
+        Initialize mode configration
+
+        Args:
+            t_mode (int): Temperature mode (defaults to 1)
+            p_mode (int): Pressure mode (defaults to 5)
+            h_mode (int): Humidity mode (defaults to 1)
+            standby (int): Standby duration (defaults to 3 (250ms))
+            filter (int): IIR filter (defaults to off - 0)
         """
+
         super().__init__(*args, **kwargs)
 
         # Check arguments
@@ -194,7 +202,7 @@ class BME280(I2CSensor):
             raise ValueError("Unexpected filter value {0}.".format(_filter))
 
         self._p_mode = p_mode
-        self._t_mode = p_mode
+        self._t_mode = t_mode
         self._h_mode = h_mode
         self._standby = standby
         self._filter = _filter
@@ -226,15 +234,18 @@ class BME280(I2CSensor):
         self.reset()
         self.exists = self.sensor_exists()
 
-    def get_serial_number(self):
+    def get_serial_number(self) -> str:
         """
         A serial number is not supported by bme280
         hence a pseudo identifier is calculated by
         adding the individual calibration values together
+
+        Returns:
+            str: Serial number information or None
         """
 
         serial_number = 0
-        for i in range(self.__REGISTER_T1_MSB, self.__REGISTER_H6)[:10]:
+        for i in range(self._REG_T1_MSB, self._REG_H6)[:10]:
             calib_parameter = self.getU8(i)
 
             if calib_parameter is not None:
@@ -248,15 +259,16 @@ class BME280(I2CSensor):
             self._logger.info("Assigned pseudo-serial number %s", serial_number)
         return serial_number
 
-    def reset(self):
+    def reset(self) -> None:
         """
         Reset sensor to default.
         """
+
         self._logger.debug("Resetting...")
-        self.txrx(self.__REGISTER_SOFTRESET, readlen=2)
+        self.txrx(self._REG_SOFTRESET, readlen=2)
         self._logger.debug("Done resetting...")
 
-    def init(self):
+    def init(self) -> None:
         """
         Initialize sensor communication
         * Activate sleep mode
@@ -266,26 +278,30 @@ class BME280(I2CSensor):
         * Write pressure oversampling rate
         """
         # Sleep mode
-        self.txrx([self.__REGISTER_CONTROL, 0x24], readlen=0)
+        self.txrx([self._REG_CONTROL, 0x24], readlen=0)
         time.sleep(self._delay)
 
         # Setup filter and standby
         cmd = (self._standby << 5) | (self._filter << 2)
-        self.txrx([self.__REGISTER_CONFIG, cmd], readlen=0)
+        self.txrx([self._REG_CONFIG, cmd], readlen=0)
         time.sleep(self._delay)
 
         # Set humidity oversampling
-        self.txrx([self.__REGISTER_CONTROL_HUM, self._h_mode], readlen=0)
+        self.txrx([self._REG_CONTROL_HUM, self._h_mode], readlen=0)
 
         # Set Temp/Pressure Oversample and enter Normal mode
-        cmd = (self._t_mode << 5) | (self._p_mode << 2) | 3
-        self.txrx([self.__REGISTER_CONTROL, cmd], readlen=0)
+        cmd = (self._t_mode << 5) + (self._p_mode << 2) + self._MODE_NORMAL
 
-    def sensor_exists(self):
+        self.txrx([self._REG_CONTROL, cmd], readlen=0)
+
+    def sensor_exists(self) -> bool:
         """
-        test if sensor is plugged in and works proper
-        :return: [BOOLEAN] True if test was successful otherwise False
+        Test if sensor is plugged in and works proper
+
+        Returns:
+            bool: True if test was successful, otherwise False.
         """
+
         # Check if sensor is responsive
         serial_number = self.get_serial_number()
         self._logger.info("Pseudo serial number %s", serial_number)
@@ -299,38 +315,42 @@ class BME280(I2CSensor):
             self.exists = False
         return self.exists
 
-    def load_calibration(self):
+    def load_calibration(self) -> bool:
         """
         Load all calibration data needed for the calculation of
         Temperature, Humidtiy and absolute pressure.
+
+        Returns:
+            bool: True if read has been completed successfully, False otherwise.
         """
-        self.param_t1 = self.getU16(self.__REGISTER_T1_MSB, self.__REGISTER_T1_LSB)
+
+        self.param_t1 = self.getU16(self._REG_T1_MSB, self._REG_T1_LSB)
         if self.param_t1 is None:
             return False
 
-        self.param_t2 = self.getS16(self.__REGISTER_T2_MSB, self.__REGISTER_T2_LSB)
-        self.param_t3 = self.getS16(self.__REGISTER_T3_MSB, self.__REGISTER_T3_LSB)
+        self.param_t2 = self.getS16(self._REG_T2_MSB, self._REG_T2_LSB)
+        self.param_t3 = self.getS16(self._REG_T3_MSB, self._REG_T3_LSB)
 
-        self.param_p1 = self.getU16(self.__REGISTER_P1_MSB, self.__REGISTER_P1_LSB)
-        self.param_p2 = self.getS16(self.__REGISTER_P2_MSB, self.__REGISTER_P2_LSB)
-        self.param_p3 = self.getS16(self.__REGISTER_P3_MSB, self.__REGISTER_P3_LSB)
-        self.param_p4 = self.getS16(self.__REGISTER_P4_MSB, self.__REGISTER_P4_LSB)
-        self.param_p5 = self.getS16(self.__REGISTER_P5_MSB, self.__REGISTER_P5_LSB)
-        self.param_p6 = self.getS16(self.__REGISTER_P6_MSB, self.__REGISTER_P6_LSB)
-        self.param_p7 = self.getS16(self.__REGISTER_P7_MSB, self.__REGISTER_P7_LSB)
-        self.param_p8 = self.getS16(self.__REGISTER_P8_MSB, self.__REGISTER_P8_LSB)
-        self.param_p9 = self.getS16(self.__REGISTER_P9_MSB, self.__REGISTER_P9_LSB)
+        self.param_p1 = self.getU16(self._REG_P1_MSB, self._REG_P1_LSB)
+        self.param_p2 = self.getS16(self._REG_P2_MSB, self._REG_P2_LSB)
+        self.param_p3 = self.getS16(self._REG_P3_MSB, self._REG_P3_LSB)
+        self.param_p4 = self.getS16(self._REG_P4_MSB, self._REG_P4_LSB)
+        self.param_p5 = self.getS16(self._REG_P5_MSB, self._REG_P5_LSB)
+        self.param_p6 = self.getS16(self._REG_P6_MSB, self._REG_P6_LSB)
+        self.param_p7 = self.getS16(self._REG_P7_MSB, self._REG_P7_LSB)
+        self.param_p8 = self.getS16(self._REG_P8_MSB, self._REG_P8_LSB)
+        self.param_p9 = self.getS16(self._REG_P9_MSB, self._REG_P9_LSB)
 
-        self.param_h1 = self.getU8(self.__REGISTER_H1)
-        self.param_h2 = self.getS16(self.__REGISTER_H2_MSB, self.__REGISTER_H2_LSB)
-        self.param_h3 = self.getU8(self.__REGISTER_H3)
-        self.param_h4 = (self.getU8(self.__REGISTER_H4_MSB) << 4) + (
-            self.getU8(self.__REGISTER_H4_LSB) & 0x0F
+        self.param_h1 = self.getU8(self._REG_H1)
+        self.param_h2 = self.getS16(self._REG_H2_MSB, self._REG_H2_LSB)
+        self.param_h3 = self.getU8(self._REG_H3)
+        self.param_h4 = (self.getU8(self._REG_H4_MSB) << 4) + (
+            self.getU8(self._REG_H4_LSB) & 0x0F
         )
-        self.param_h5 = (self.getU8(self.__REGISTER_H5_MSB) << 4) + (
-            (self.getU8(self.__REGISTER_H5_LSB) >> 4) & 0x0F
+        self.param_h5 = (self.getU8(self._REG_H5_MSB) << 4) + (
+            (self.getU8(self._REG_H5_LSB) >> 4) & 0x0F
         )
-        self.param_h6 = self.getS8(self.__REGISTER_H6)
+        self.param_h6 = self.getS8(self._REG_H6)
 
         self._logger.debug("t1 = %s", self.param_t1)
         self._logger.debug("t2 = %s", self.param_t2)
@@ -355,21 +375,28 @@ class BME280(I2CSensor):
 
         return True
 
-    def prepare_measurement(self):
+    def prepare_measurement(self) -> bool:
         """
         Placeholder function to be compatible with other sensor classes
+
+        Returns:
+            bool: True if test was successful, otherwise False.
         """
+
         if self.load_calibration():
             self.init()
             return True
         else:
             return False
 
-    def get_data(self):
+    def get_data(self) -> dict:
         """
         Get current measurement values
-        :return: data dictionary
+
+        Returns:
+            dict: Data dictionary
         """
+
         # Wait until data is ready
         if self.error is not None:
             res = self.prepare_measurement()
@@ -429,51 +456,77 @@ class BME280(I2CSensor):
 
         return self.data
 
-    def get_raw_data(self):
+    def get_raw_data(self) -> bytearray:
         """
         Read all values from devices needed to calculate
         humidity, pressure and temperature values
+
+        Returns:
+            bytearray: Raw data array
         """
+
         i = 0
         while i < self._max_attempts:
-            state = self.getU8([self.__REGISTER_STATUS])
+            state = self.getU8([self._REG_STATUS])
             if state is not None and state & 0x08:
                 time.sleep(self._delay)
             elif state is None:
                 return None
             i += 1
-        return self.txrx([self.__REGISTER_DATA], 8)
+        return self.txrx([self._REG_DATA], 8)
 
     @classmethod
-    def read_raw_temp(cls, raw_data):
+    def read_raw_temp(cls, raw_data: bytearray) -> int:
         """
-        Returns the raw (uncompensated) temperature from the sensor.
+        Calculate uncompensated raw temperature from sensor.
+
+        Returns:
+            int: Raw adc read
         """
-        raw = (raw_data[3] << 12) | (raw_data[4] << 4) | ((raw_data[5] >> 4) & 0x0F)
+
+        raw = (raw_data[3] << 16) | (raw_data[4] << 8) | (raw_data[5])
+        raw >>= 4
         return raw
 
     @classmethod
-    def read_raw_pressure(cls, raw_data):
+    def read_raw_pressure(cls, raw_data: bytearray) -> int:
         """
-        Returns the raw (uncompensated) pressure level from the sensor.
+        Calculate raw (uncompensated) pressure level from the sensor.
+
+        Returns:
+            int: Raw adc read
         """
+
         raw = (raw_data[0] << 12) | (raw_data[1] << 4) | (raw_data[2] >> 4 & 0x0F)
         return raw
 
     @classmethod
-    def read_raw_humidity(cls, raw_data):
+    def read_raw_humidity(cls, raw_data: bytearray) -> int:
         """
-        Returns the raw (uncompensated) humidity value from the sensor.
+        Calculate raw (uncompensated) humidity value from the sensor.
+
+        Args:
+            raw_data (bytearray): Full raw data array (temperature,pressure and humidity)
+
+        Returns:
+            int: Raw adc read
         """
+
         raw = (raw_data[6] << 8) | raw_data[7]
         if raw is not None and raw is int:
             if raw > 32767:
                 raw -= 65536
         return raw
 
-    def read_temperature(self, raw_data):
+    def read_temperature(self, raw_data: bytearray) -> float:
         """
-        Gets the compensated temperature in degrees celsius.
+        Convert raw temperature to compensated temperature in °C
+
+        Args:
+            raw_data (bytearray): Full raw data array (temperature,pressure and humidity)
+
+        Returns:
+            float: Temperature in °C or None if conversion failed
         """
 
         adc = self.read_raw_temp(raw_data)
@@ -482,21 +535,26 @@ class BME280(I2CSensor):
         if adc is None:
             self._logger.error("Temperature data not valid.")
         elif None not in [self.param_t1, self.param_t2, self.param_t3]:
-            var1 = ((adc / 2.0 ** 14) - (self.param_t1 / 2.0 ** 10)) * self.param_t2
-            var2 = (
-                (adc / 131072.0 - float(self.param_t1) / 8192.0)
-                * (adc / 2.0 ** 17 - self.param_t1 / 2.0 ** 13)
-            ) * float(self.param_t3)
-
+            var1 = (adc / 16384.0 - self.param_t1 / 1024.0) * self.param_t2
+            var2 = ((adc / 131072.0 - self.param_t1 / 8192.0) ** 2) * self.param_t3
             self.t_fine = var1 + var2
-            temp = (var1 + var2) / 5120.0
-            return temp
+            return self.t_fine / 5120.0
+
         else:
             self._logger.error("Calibration data not available.")
         return None
 
-    def read_pressure(self, raw_data):
-        """Gets the compensated pressure in Pascals."""
+    def read_pressure(self, raw_data: bytearray) -> float:
+        """
+        Convert raw pressure to compensated pressure in Pa
+
+        Args:
+            raw_data (bytearray): Full raw data array (temperature,pressure and humidity)
+
+        Returns:
+            float: Pressure in Pa
+        """
+
         adc = self.read_raw_pressure(raw_data)
         self._logger.debug("Pressure raw data %s", adc)
 
@@ -517,49 +575,45 @@ class BME280(I2CSensor):
         abs_p = abs_p + (var1 + var2 + float(self.param_p7)) / 16.0
         return abs_p
 
-    def read_humidity(self, raw_data):
+    def read_humidity(self, raw_data: bytearray) -> float:
         """
-        Calculate humidity.
+        Convert raw rel. humidity to compensated relative humidity in %
+
+        Args:
+            raw_data (bytearray): Full raw data array (temperature,pressure and humidity)
+
+        Returns:
+            float: Relative humidity in %
         """
+
         adc = self.read_raw_humidity(raw_data)
         self._logger.debug("Humidity raw data %s", adc)
 
-        humidity = float(self.t_fine) - 76800.0
-        humidity = (
-            float(adc)
-            - (float(self.param_h4) * 64.0 + float(self.param_h5) / 16384.0 * humidity)
-        ) * (
-            float(self.param_h2)
-            / 65536.0
-            * (
-                1.0
-                + float(self.param_h6)
-                / 67108864.0
-                * humidity
-                * (1.0 + float(self.param_h3) / 67108864.0 * humidity)
-            )
-        )
-        humidity = humidity * (1.0 - float(self.param_h1) * humidity / 524288.0)
-
-        if humidity > 100:
-            humidity = 100
-        elif humidity < 0:
-            humidity = 0
-
+        # Algorithm from the BME280 driver
+        # https://github.com/BoschSensortec/BME280_driver/blob/master/bme280.c
+        var1 = float(self.t_fine) - 76800.0
+        var2 = self.param_h4 * 64.0 + (self.param_h5 / 16384.0) * var1
+        var3 = adc - var2
+        var4 = self.param_h2 / 65536.0
+        var5 = 1.0 + (self.param_h3 / 67108864.0) * var1
+        var6 = 1.0 + (self.param_h6 / 67108864.0) * var1 * var5
+        var6 = var3 * var4 * var5 * var6
+        res = var6 * (1.0 - self.param_h1 * var6 / 524288.0)
+        humidity = max(0.0, min(res, 100.0))
         return humidity
 
-    def read_dewpoint(self, raw_data):
+    def read_dewpoint(self, raw_data: bytearray) -> float:
         """
-        Return calculated dewpoint in C, only accurate at > 50% RH
+        Return calculated dewpoint in °C, only accurate at > 50% RH
         """
         celsius = self.read_temperature(raw_data)
         humidity = self.read_humidity(raw_data)
         dewpoint = celsius - ((100 - humidity) / 5)
         return dewpoint
 
-    def read_dewpoint_f(self, raw_data):
+    def read_dewpoint_f(self, raw_data: bytearray) -> float:
         """
-        Return calculated dewpoint in F, only accurate at > 50% RH
+        Calculated dewpoint in F, only accurate at > 50% RH
         """
         dewpoint_c = self.read_dewpoint(raw_data)
         dewpoint_f = dewpoint_c * 1.8 + 32
