@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -29,15 +29,17 @@ class SFM(I2CSensor):
     _offset = None
     _scale = None
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.reset()
         self.exists = self.sensor_exists()
 
     def sensor_exists(self) -> bool:
         """
-        test if sensor is plugged on and works proper
-        :return: [BOOLEAN] True if test was successful otherwise False
+        Test if sensor is plugged on and works proper
+
+        Returns:
+            bbol: True if test was successful, false otherwise.
         """
         serial_number = self.get_serial_number()
         attempt = 0
@@ -58,9 +60,12 @@ class SFM(I2CSensor):
 
     def reset(self) -> bool:
         """
-        reseting the sensor
-        :return: True for successful reset else False
+        Reseting the sensor
+
+        Returns:
+            bool: True for successful reset else False
         """
+
         try:
             self.txrx([0x20, 0x00], readlen=0)
             time.sleep(0.1)
@@ -70,9 +75,12 @@ class SFM(I2CSensor):
 
     def get_serial_number(self) -> Union[str, None]:
         """
-        reads unique serial number of sensor
-        :return: [STRING] serial number of the sensor
+        Reads unique serial number of sensor.
+
+        Returns:
+            str: Serial number of the sensor
         """
+
         serial_number = 0
         self.error = None
         data = self.txrx([0x31, 0xAE], readlen=6)
@@ -96,11 +104,14 @@ class SFM(I2CSensor):
         self._logger.debug("Got serial number: %s", serial_number)
         return serial_number
 
-    def prepare_measurement(self):
+    def prepare_measurement(self) -> bool:
         """
-        initialises a continuous measurement of the mass flow
-        :return: [BOOLEAN]: continuous measurement established (True = successful | False = failed)
+        Initializes a continuous measurement of the mass flow.
+
+        Returns:
+            bool: Continuous measurement established (True = successful | False = failed)
         """
+
         self._scale = self.get_scale_factor()
         if self._scale is None:
             return self.error
@@ -133,6 +144,13 @@ class SFM(I2CSensor):
         return self.error
 
     def get_scale_factor(self) -> Union[int, None]:
+        """
+        Read conversion factor from sensor.
+
+        Returns:
+            (int, None): Scale factor or in case of an error None
+        """
+
         data = self.txrx([0x30, 0xDE], readlen=3)
         if Error.checksum([data[0], data[1]], data[2], crc_init=0x00)[1]:
             scale_factor = self.bytes_to_u16(data[0], data[1])
@@ -142,6 +160,13 @@ class SFM(I2CSensor):
             return None
 
     def get_offset(self) -> Union[int, None]:
+        """
+        Read offset value from sensor.
+
+        Returns:
+            (int, None): Scale factor or in case of an error None
+        """
+
         data = self.txrx([0x30, 0xDF], readlen=3)
         if Error.checksum([data[0], data[1]], data[2], crc_init=0x00)[1]:
             offset = self.bytes_to_u16(data[0], data[1])
@@ -150,13 +175,14 @@ class SFM(I2CSensor):
             self.error = Error().crc
             return None
 
-    def get_data(self):
+    def get_data(self) -> dict:
         """
-        :param scale_factor: sensor specific parameter for the calculation of the volumeflow
-        :param offset: sensor specific parameter for the calculation of the volumeflow
-        :return: data dictionary
-        :rtype: dict
+        Read data array.
+
+        Returns:
+            dict: Data dictionary
         """
+
         res = self.txrx([], readlen=3)
         self._logger.debug("Result bytes: %s", res)
         self.data = self.default_data()
@@ -187,9 +213,13 @@ class SFM(I2CSensor):
             self.error = Error().read(self)
             return self.error
 
+
 class SFMXXX(SFM):
+    """ Deprecated class identifier. Use SFM instead."""
     pass
 
+
 class SFM3XXX(SFM):
+    """ Deprecated class identifier. Use SFM instead."""
     pass
 
